@@ -12,7 +12,7 @@ int main(int argc, char *argv[])
 
     QTranslator myappTranslator;
     myappTranslator.load(":/translation/qtranslate_" + QLocale::system().name());
-    qDebug() << "qtranslate_" << QLocale::system().name();
+    //qDebug() << "qtranslate_" << QLocale::system().name();
     a.installTranslator(&myappTranslator);
 
     MainWindow w;
