@@ -106,6 +106,10 @@ MainWindow::MainWindow(QWidget *parent) :
     _accessManager = new QNetworkAccessManager(this);
     _toWindow = 0;
 
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
+
     createMenu();
     createComponents();
     createPortraitLayout();
@@ -119,10 +123,6 @@ MainWindow::MainWindow(QWidget *parent) :
 
     retranslateUi();
     loadSettings();
-
-#ifdef Q_WS_MAEMO_5
-    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-#endif
 }
 
 void MainWindow::createMenu()
@@ -149,22 +149,17 @@ void MainWindow::createMenu()
     //actionDonate->setObjectName(QString::fromUtf8("actionDonate"));
 
     QMenuBar * menuBar = new QMenuBar(this);
-    menuBar->setObjectName(QString::fromUtf8("menuBar"));
-    menuBar->setGeometry(QRect(0, 0, 800, 21));
-    Fremantle = new QMenu(menuBar);
-    Fremantle->setObjectName(QString::fromUtf8("Fremantle"));
-    this->setMenuBar(menuBar);
 
-    menuBar->addAction(Fremantle->menuAction());
-    Fremantle->addAction(actionLeft_from_clipboard);
-    Fremantle->addAction(actionRight_from_clipboard);
-    Fremantle->addAction(actionLeft_to_clipboard);
-    Fremantle->addAction(actionRight_to_clipboard);
-    Fremantle->addAction(actionLeft_as_sms);
-    Fremantle->addAction(actionRight_as_sms);
-    Fremantle->addAction(actionLeft_as_e_mail);
-    Fremantle->addAction(actionRight_as_e_mail);
-    Fremantle->addAction(actionAbout_qtranslate);
+    menuBar->addAction(actionLeft_from_clipboard);
+    menuBar->addAction(actionRight_from_clipboard);
+    menuBar->addAction(actionLeft_to_clipboard);
+    menuBar->addAction(actionRight_to_clipboard);
+    menuBar->addAction(actionLeft_as_sms);
+    menuBar->addAction(actionRight_as_sms);
+    menuBar->addAction(actionLeft_as_e_mail);
+    menuBar->addAction(actionRight_as_e_mail);
+    menuBar->addAction(actionAbout_qtranslate);
+    setMenuBar(menuBar);
     //Fremantle->addAction(actionDonate);
 }
 
@@ -309,7 +304,6 @@ void MainWindow::retranslateUi()
     //actionDonate->setText(QApplication::translate("MainWindow", "Donate", 0, QApplication::UnicodeUTF8));
     buttonLeft_clear->setText(QApplication::translate("MainWindow", "Clear", 0, QApplication::UnicodeUTF8));
     buttonRight_clear->setText(QApplication::translate("MainWindow", "Clear", 0, QApplication::UnicodeUTF8));
-    Fremantle->setTitle(QApplication::translate("MainWindow", "Fremantle", 0, QApplication::UnicodeUTF8));
 }
 
 void MainWindow::saveSettings() {
@@ -322,8 +316,8 @@ void MainWindow::saveSettings() {
 
 void MainWindow::loadSettings() {
     QSettings settings("Peter Bouda", "qTranslate");
-    QString currentLeftLang = settings.value("leftLanguage", "Afrikaans").toString();
-    QString currentRightLang = settings.value("rightLanguage", "Afrikaans").toString();
+    QString currentLeftLang = settings.value("leftLanguage", "de").toString();
+    QString currentRightLang = settings.value("rightLanguage", "en").toString();
     comboboxLang_left->setCurrentIndex(comboboxLang_left->findText(currentLeftLang));
     comboboxLang_right->setCurrentIndex(comboboxLang_right->findText(currentRightLang));
 }
@@ -349,7 +343,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::aboutQTranslate()
 {
-    QMessageBox::information(this, tr("About qTranslate"),tr("qTranslate - A translation software for Maemo, Symbian and MeeGo<br>v1.0.0<br>based on Google Translate<br>Find more information and support us on <a href=\"http://mobileqt.de/apps/qtranslate\">the qTranslate website</a>"));
+    QMessageBox::information(this, tr("About qTranslate"),tr("qTranslate - A translation software for Maemo, Symbian and MeeGo<br>") + "v1.0.3<br>" + tr("based on Google Translate<br>Find more information and support on <a href=\"http://mobileqt.de/apps/qtranslate\">the qTranslate website</a>."));
 }
 
 void MainWindow::leftClear()
@@ -506,7 +500,7 @@ void MainWindow::resizeEvent(QResizeEvent* event) {
 #endif
 
     QRect qs=QApplication::desktop()->availableGeometry();
-    if(qs.height() > qs.width()) {
+    if (event->size().height() > event->size().width()) {
         QIcon icon;
         icon.addFile(QString::fromUtf8(":/images/images/arrowdown.png"), QSize(), QIcon::Normal, QIcon::Off);
         buttonLeft_to_right->setIcon(icon);
@@ -527,7 +521,7 @@ void MainWindow::createLangCodes()
 {
     QMap<QString, QString> langCodes;
 
-    langCodes[tr("Afrikanns")] = "af";
+    langCodes[tr("Afrikaans")] = "af";
     langCodes[tr("Albanian")] = "sq";
     langCodes[tr("Arabic")] = "ar";
     langCodes[tr("Bulgarian")] = "bg";
@@ -589,12 +583,12 @@ void MainWindow::translateRequestFinished(QNetworkReply * reply)
  {
     if (reply->error() != QNetworkReply::NoError) {
         QMessageBox::information(this, tr("HTTP"),
-                                  tr("Translation failed: %1.")
+                                  tr("Could not connect to the translation server. Please check that offline mode is disabled and device is able to connect to a network. (%1)")
                                   .arg(reply->errorString()));
     } else {
         bool ok = false;
         QString jsonTranslation = unescapeJson(reply->readAll(), &ok).trimmed();
-        qDebug() << jsonTranslation;
+        //qDebug() << jsonTranslation;
         QString translation = QString("");
         QRegExp regexp = QRegExp("\"translatedText\":\"(.*)\"");
         regexp.setPatternSyntax(QRegExp::RegExp2);
